// Demonstrates how to receive data from the Arduino board, in order to 
// turn on and off a virtual pixel
// 
// Created March 2013
// by Peter Peters

import processing.serial.*; 

int boxSize = 20;
int lf = 10;
Serial port; 

void setup() {
  size(200, 200);

  // List all the available serial ports in the output pane. 
  // Choose the port that the Arduino board is connected to from this list.
  // The first port in the list is port #0 

    println(Serial.list()); 

  // Open the port that the Arduino board is connected to (in this case #0) 
  // Make sure to open the port at the same speed Arduino is using (9600bps)

  port = new Serial(this, Serial.list()[1], 38400);
  port.bufferUntil(lf);
}

color fillColor = color(0,0,0);

void draw() 
{ 
  drawCenteredBox(fillColor);
}

void drawCenteredBox(color col) {
  fill(col);
  rect((width/2)-(boxSize/2), (height/2)-(boxSize/2), 
  (boxSize), boxSize);
}

// We assume every now and then a line containing a single int
// value is received, ended by a newline, e.g. sent by an arduino 
// with some analog sensor
void serialEvent(Serial myPort) {
  // here the "readable text received is converted to an actual value
  // first strip excess spaces, linefeeds, etc.
  String instring = trim(myPort.readString());
  // convert the text string to an int value (we assume tha this is possible
  // so no invalid characters should be in the string, only '0'..'9')
  int inval = int(instring);
  // map the range of the sensor value to 0..255. The 600/1023 values 
  // used here should be replaces by values dependent on YOUR sensor 
  // range.
  if (inval < 50) fillColor = color(255,0,0);
  else fillColor = color(255,255,255);
}

